@@ -1,7 +1,7 @@
 # ABSTRACT: Fix version issues to support all the things
 package App::ElasticSearch::Utilities::VersionHacks;
 
-our $VERSION = '3.8'; # VERSION
+our $VERSION = '3.9'; # VERSION
 use strict;
 use warnings;
 
@@ -25,6 +25,7 @@ my %SIMPLE = (
         1.2     => '_nodes',
         1.3     => '_nodes',
         1.4     => '_nodes',
+        1.5     => '_nodes',
     }
 );
 my %CALLBACKS = (
@@ -38,6 +39,7 @@ my %CALLBACKS = (
         1.2 => \&_cluster_state_1_0,
         1.3 => \&_cluster_state_1_0,
         1.4 => \&_cluster_state_1_0,
+        1.5 => \&_cluster_state_1_0,
     },
 );
 
@@ -54,6 +56,9 @@ sub _fix_version_request {
         if(my $err = $@) {
             output({stderr=>1,color=>'red'}, "Failed version detection!", $@);
         }
+        if ($version < 1.0) {
+            output({stderr=>1,color=>'red',sticky=>1}, "!!! Detected ElasticSearch Version '$version', which is not going to be supported in future releases !!!");
+        }
     }
 
     return @_ unless defined $version;
@@ -166,7 +171,7 @@ App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all
 
 =head1 VERSION
 
-version 3.8
+version 3.9
 
 =head1 AUTHOR
 
